Pandokia

PAGEHEADER

- Lists of Test Runs:
  - All
  - daily_*
  - user_* - test runs that took the default name
  - enter a pattern here

- Latest Daily Report (table)
  - problem: tree list or
  - Latest Daily Report (tree walker)

- List of interesting QID
- key_id :

  User Preferences

- Enter your own tree walk parameters:
  (if you have a lot of data, it can be very slow to submit this form with all fields set to "*") test_run:
  project:
  host:
  test_name:

expected tests summary